## 1.0.5 (2022-10-21)

- Updated value processing to ease debugging: append all values to list, then process it
- Updated tests

## 1.0.4 (2022-10-21)

- Updated value processing: empty string should not be dumped. Only dump None values.
- Updated README

## 1.0.3 (2022-10-21)

[Missed CHANGELOG update]

## 1.0.2 (2022-10-14)

- Added case sensitivity option in Confita

## 1.0.1 (2022-10-13)

- Updated setup.py and tools

## 1.0.0 (2022-10-13)

- Initialized package
- Added Vault backend
- Added File backend (YAML format)
- Added Dict backend
- Added Environment backend
- Added explicit type conversion support (str, bool, int, float)
